﻿using Blazor.Models;
using Blazorise.Extensions;
using Microsoft.AspNetCore.Components;

namespace Blazor.Components
{
    public partial class ItemInventory
    {
        [Parameter]
        public bool NoDrop { get; set; }

        [Parameter]
        public InventoryItem Items { get; set; }

        [Parameter]
        public int Index { get; set; }

        [CascadingParameter]
        public Inventory Parent { get; set; }

        public void OnDragStart()
        {
            if(!this.NoDrop)
            {
                Parent.CurrentDragItem = null;
                return;
            }
            Parent.CurrentDragItem = this.Items;
            Parent.inventory.inventoryItems[this.Index] = null;
            this.NoDrop = false;
            if (this.Items == null) return;
            Parent.Actions.Add(new InventoryAction("On drag start",this.Index,Items.item));
            Parent.update();
        }
        

        public void OnDrop()
        {
            if (!this.NoDrop)
            {
                this.Items = Parent.CurrentDragItem;
                this.NoDrop = true;
                Parent.CurrentDragItem = null;
                Parent.inventory.inventoryItems[this.Index] = this.Items;
                if (this.Items == null) return;
                Parent.Actions.Add(new InventoryAction("On Drop",this.Index,Items.item));
                Parent.update();
                return;
            }
            if(Parent.CurrentDragItem == null)
            {
                return;
            }
            if (Parent.CurrentDragItem.item.Id != this.Items.item.Id)
            {
                this.Items = Parent.CurrentDragItem;
                this.NoDrop= true;
                Parent.CurrentDragItem = null;
                Parent.inventory.inventoryItems[this.Index] = this.Items;
                Parent.Actions.Add(new InventoryAction("On drag start",this.Index,Items.item));
                Parent.update();
                return;
            }
            else
            {       
                int total = Parent.CurrentDragItem.Stack + this.Items.Stack;
                if (total >this.Items.item.StackSize)
                {
                    this.Items.Stack = this.Items.item.StackSize;
                    Parent.CurrentDragItem = null;
                    Parent.Actions.Add(new InventoryAction("On drag start",this.Index,Items.item));
                    Parent.inventory.inventoryItems[this.Index] = this.Items;
                    Parent.update();
                    return;
                }
                else
                {
                    this.Items.Stack = total;
                    Parent.CurrentDragItem = null;
                    Parent.inventory.inventoryItems[this.Index] = this.Items;
                    Parent.update();
                    return;
                }
            }
        }
        internal void OnDragEnter()
        {
            if (this.Items == null) return;
            Parent.Actions.Add(new InventoryAction("Drag Enter",this.Index,Items.item));
        }

        internal void OnDragLeave()
        {
            if (this.Items == null) return;
            Parent.Actions.Add(new InventoryAction("Drag Leave",this.Index,Items.item));
        }
    }
}
